df_typecast_all: Typecast all columns of a data.frame of a specific type
Description
Bulk convert columns of a data.frame that share a certain class to a different
class. Use with care, will introduce NAs for some conversion attempts
Usage
df_typecast_all(dat, from = "factor", to = "character")
Value
a data frame with all columns of class from converted to class to
Arguments
- dat
a data.frame
- from
column type to cast
- to
target column type