Tatto_table is the superclass of all the *_table classes made available
by this package. Each Tatoo_table provides a different way of combining
several tables (data.frames) into a single table. Those tables can then
be exported via as_workbook()/save_xlsx(). In the future, support for
latex and html export is also planned.
tatoo_table(dat)an object of any of the classes listed in the description
Currently, the following subclasses exists:
Tagged_table
Composite_table
Mashed_table
Stacked_table
The tatoo_table() function is just a constructor used internally and you
will not need to use it except if your planning on extending this package
with your own code.
Other Tatoo tables:
comp_table(),
mash_table(),
stack_table(),
tag_table()